componenttools.get_improper_descendents_of_component_that_cross_offset
======================================================================

.. autofunction:: abjad.tools.componenttools.get_improper_descendents_of_component_that_cross_offset.get_improper_descendents_of_component_that_cross_offset
   :noindex:
